@@ -36,7 +36,7 @@ func Run() (err error) {
 	app := cli.NewApp()
 	app.Name = "croc"
 	if Version == "" {
-		Version = "v10.3.0"
+		Version = "v10.3.1"
 	}
 	app.Version = Version
 	app.Compiled = time.Now()
@@ -96,6 +96,19 @@ func Run() (err error) {
 				&cli.IntFlag{Name: "transfers", Value: 5, Usage: "number of ports to use for relay"},
 			},
 		},
+		{
+			Name:   "generate-fish-completion",
+			Usage:  "generate fish completion and output to stdout",
+			Hidden: true,
+			Action: func(ctx *cli.Context) error {
+				completion, err := ctx.App.ToFishCompletion()
+				if err != nil {
+					return err
+				}
+				fmt.Print(completion)
+				return nil
+			},
+		},
 	}
 	app.Flags = []cli.Flag{
 		&cli.BoolFlag{Name: "internal-dns", Usage: "use a built-in DNS stub resolver rather than the host operating system"},
